==> pulumi-azure-native-kotlin-2.19.0.0-sources.jar: com/pulumi/azurenative/connectedvmwarevsphere/kotlin/inputs/VirtualDiskArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.connectedvmwarevsphere.kotlin.inputs

import com.pulumi.azurenative.connectedvmwarevsphere.inputs.VirtualDiskArgs.builder
import com.pulumi.azurenative.connectedvmwarevsphere.kotlin.enums.DiskMode
import com.pulumi.azurenative.connectedvmwarevsphere.kotlin.enums.DiskType
import com.pulumi.core.Either
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.Int
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 * Virtual disk model
 * @property controllerKey Gets or sets the controller id.
 * @property deviceKey Gets or sets the device key value.
 * @property deviceName Gets or sets the device name.
 * @property diskMode Gets or sets the disk mode.
 * @property diskSizeGB Gets or sets the disk total size.
 * @property diskType Gets or sets the disk backing type.
 * @property name Gets or sets the name of the virtual disk.
 * @property unitNumber Gets or sets the unit number of the disk on the controller.
 */
public data class VirtualDiskArgs(
    public val controllerKey: Output<Int>? = null,
    public val deviceKey: Output<Int>? = null,
    public val deviceName: Output<String>? = null,
    public val diskMode: Output<Either<String, DiskMode>>? = null,
    public val diskSizeGB: Output<Int>? = null,
    public val diskType: Output<Either<String, DiskType>>? = null,
    public val name: Output<String>? = null,
    public val unitNumber: Output<Int>? = null,
) : ConvertibleToJava<com.pulumi.azurenative.connectedvmwarevsphere.inputs.VirtualDiskArgs> {
    override fun toJava(): com.pulumi.azurenative.connectedvmwarevsphere.inputs.VirtualDiskArgs =
        com.pulumi.azurenative.connectedvmwarevsphere.inputs.VirtualDiskArgs.builder()
            .controllerKey(controllerKey?.applyValue({ args0 -> args0 }))
            .deviceKey(deviceKey?.applyValue({ args0 -> args0 }))
            .deviceName(deviceName?.applyValue({ args0 -> args0 }))
            .diskMode(
                diskMode?.applyValue({ args0 ->
                    args0.transform({ args0 -> args0 }, { args0 ->
                        args0.let({ args0 -> args0.toJava() })
                    })
                }),
            )
            .diskSizeGB(diskSizeGB?.applyValue({ args0 -> args0 }))
            .diskType(
                diskType?.applyValue({ args0 ->
                    args0.transform({ args0 -> args0 }, { args0 ->
                        args0.let({ args0 -> args0.toJava() })
                    })
                }),
            )
            .name(name?.applyValue({ args0 -> args0 }))
            .unitNumber(unitNumber?.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [VirtualDiskArgs].
 */
@PulumiTagMarker
public class VirtualDiskArgsBuilder internal constructor() {
    private var controllerKey: Output<Int>? = null

    private var deviceKey: Output<Int>? = null

    private var deviceName: Output<String>? = null

    private var diskMode: Output<Either<String, DiskMode>>? = null

    private var diskSizeGB: Output<Int>? = null

    private var diskType: Output<Either<String, DiskType>>? = null

    private var name: Output<String>? = null

    private var unitNumber: Output<Int>? = null

    /**
     * @param value Gets or sets the controller id.
     */
    @JvmName("cccosplljogjroyl")
    public suspend fun controllerKey(`value`: Output<Int>) {
        this.controllerKey = value
    }

    /**
     * @param value Gets or sets the device key value.
     */
    @JvmName("fqhbjesbmkhcoxon")
    public suspend fun deviceKey(`value`: Output<Int>) {
        this.deviceKey = value
    }

    /**
     * @param value Gets or sets the device name.
     */
    @JvmName("fwlyurcgdeghdaps")
    public suspend fun deviceName(`value`: Output<String>) {
        this.deviceName = value
    }

    /**
     * @param value Gets or sets the disk mode.
     */
    @JvmName("rvyweoqdfehunmlu")
    public suspend fun diskMode(`value`: Output<Either<String, DiskMode>>) {
        this.diskMode = value
    }

    /**
     * @param value Gets or sets the disk total size.
     */
    @JvmName("vjpogbemvgdywfbv")
    public suspend fun diskSizeGB(`value`: Output<Int>) {
        this.diskSizeGB = value
    }

    /**
     * @param value Gets or sets the disk backing type.
     */
    @JvmName("swialqylwlbpimnn")
    public suspend fun diskType(`value`: Output<Either<String, DiskType>>) {
        this.diskType = value
    }

    /**
     * @param value Gets or sets the name of the virtual disk.
     */
    @JvmName("twnvcrmrlvbjdoqt")
    public suspend fun name(`value`: Output<String>) {
        this.name = value
    }

    /**
     * @param value Gets or sets the unit number of the disk on the controller.
     */
    @JvmName("qlihabqylamxiqsx")
    public suspend fun unitNumber(`value`: Output<Int>) {
        this.unitNumber = value
    }

    /**
     * @param value Gets or sets the controller id.
     */
    @JvmName("fhobochfuythskhc")
    public suspend fun controllerKey(`value`: Int?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.controllerKey = mapped
    }

    /**
     * @param value Gets or sets the device key value.
     */
    @JvmName("nbmvcsbbfmrlxvaw")
    public suspend fun deviceKey(`value`: Int?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.deviceKey = mapped
    }

    /**
     * @param value Gets or sets the device name.
     */
    @JvmName("rtgrvsqvmevkmnyq")
    public suspend fun deviceName(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.deviceName = mapped
    }

    /**
     * @param value Gets or sets the disk mode.
     */
    @JvmName("rcjsmekesqcqnhob")
    public suspend fun diskMode(`value`: Either<String, DiskMode>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.diskMode = mapped
    }

    /**
     * @param value Gets or sets the disk mode.
     */
    @JvmName("kjvjsnhtghtbvrju")
    public fun diskMode(`value`: String) {
        val toBeMapped = Either.ofLeft<String, DiskMode>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.diskMode = mapped
    }

    /**
     * @param value Gets or sets the disk mode.
     */
    @JvmName("gqewllosnbfjhbnp")
    public fun diskMode(`value`: DiskMode) {
        val toBeMapped = Either.ofRight<String, DiskMode>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.diskMode = mapped
    }

    /**
     * @param value Gets or sets the disk total size.
     */
    @JvmName("yaikevamimnckesr")
    public suspend fun diskSizeGB(`value`: Int?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.diskSizeGB = mapped
    }

    /**
     * @param value Gets or sets the disk backing type.
     */
    @JvmName("udueueuvdrwxfpld")
    public suspend fun diskType(`value`: Either<String, DiskType>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.diskType = mapped
    }

    /**
     * @param value Gets or sets the disk backing type.
     */
    @JvmName("vwqibfqcqkhaasvj")
    public fun diskType(`value`: String) {
        val toBeMapped = Either.ofLeft<String, DiskType>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.diskType = mapped
    }

    /**
     * @param value Gets or sets the disk backing type.
     */
    @JvmName("pimwirndguyabwhw")
    public fun diskType(`value`: DiskType) {
        val toBeMapped = Either.ofRight<String, DiskType>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.diskType = mapped
    }

    /**
     * @param value Gets or sets the name of the virtual disk.
     */
    @JvmName("udispsiitlgnxjmt")
    public suspend fun name(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.name = mapped
    }

    /**
     * @param value Gets or sets the unit number of the disk on the controller.
     */
    @JvmName("ioobefnkjdkwdtev")
    public suspend fun unitNumber(`value`: Int?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.unitNumber = mapped
    }

    internal fun build(): VirtualDiskArgs = VirtualDiskArgs(
        controllerKey = controllerKey,
        deviceKey = deviceKey,
        deviceName = deviceName,
        diskMode = diskMode,
        diskSizeGB = diskSizeGB,
        diskType = diskType,
        name = name,
        unitNumber = unitNumber,
    )
}

==> pulumi-azure-native-kotlin-2.28.0.0-sources.jar: com/pulumi/azurenative/connectedvmwarevsphere/kotlin/inputs/VirtualDiskArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.connectedvmwarevsphere.kotlin.inputs

import com.pulumi.azurenative.connectedvmwarevsphere.inputs.VirtualDiskArgs.builder
import com.pulumi.azurenative.connectedvmwarevsphere.kotlin.enums.DiskMode
import com.pulumi.azurenative.connectedvmwarevsphere.kotlin.enums.DiskType
import com.pulumi.core.Either
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.Int
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 * Virtual disk model
 * @property controllerKey Gets or sets the controller id.
 * @property deviceKey Gets or sets the device key value.
 * @property deviceName Gets or sets the device name.
 * @property diskMode Gets or sets the disk mode.
 * @property diskSizeGB Gets or sets the disk total size.
 * @property diskType Gets or sets the disk backing type.
 * @property name Gets or sets the name of the virtual disk.
 * @property unitNumber Gets or sets the unit number of the disk on the controller.
 */
public data class VirtualDiskArgs(
    public val controllerKey: Output<Int>? = null,
    public val deviceKey: Output<Int>? = null,
    public val deviceName: Output<String>? = null,
    public val diskMode: Output<Either<String, DiskMode>>? = null,
    public val diskSizeGB: Output<Int>? = null,
    public val diskType: Output<Either<String, DiskType>>? = null,
    public val name: Output<String>? = null,
    public val unitNumber: Output<Int>? = null,
) : ConvertibleToJava<com.pulumi.azurenative.connectedvmwarevsphere.inputs.VirtualDiskArgs> {
    override fun toJava(): com.pulumi.azurenative.connectedvmwarevsphere.inputs.VirtualDiskArgs =
        com.pulumi.azurenative.connectedvmwarevsphere.inputs.VirtualDiskArgs.builder()
            .controllerKey(controllerKey?.applyValue({ args0 -> args0 }))
            .deviceKey(deviceKey?.applyValue({ args0 -> args0 }))
            .deviceName(deviceName?.applyValue({ args0 -> args0 }))
            .diskMode(
                diskMode?.applyValue({ args0 ->
                    args0.transform({ args0 -> args0 }, { args0 ->
                        args0.let({ args0 -> args0.toJava() })
                    })
                }),
            )
            .diskSizeGB(diskSizeGB?.applyValue({ args0 -> args0 }))
            .diskType(
                diskType?.applyValue({ args0 ->
                    args0.transform({ args0 -> args0 }, { args0 ->
                        args0.let({ args0 -> args0.toJava() })
                    })
                }),
            )
            .name(name?.applyValue({ args0 -> args0 }))
            .unitNumber(unitNumber?.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [VirtualDiskArgs].
 */
@PulumiTagMarker
public class VirtualDiskArgsBuilder internal constructor() {
    private var controllerKey: Output<Int>? = null

    private var deviceKey: Output<Int>? = null

    private var deviceName: Output<String>? = null

    private var diskMode: Output<Either<String, DiskMode>>? = null

    private var diskSizeGB: Output<Int>? = null

    private var diskType: Output<Either<String, DiskType>>? = null

    private var name: Output<String>? = null

    private var unitNumber: Output<Int>? = null

    /**
     * @param value Gets or sets the controller id.
     */
    @JvmName("vtjslbeodecrxptf")
    public suspend fun controllerKey(`value`: Output<Int>) {
        this.controllerKey = value
    }

    /**
     * @param value Gets or sets the device key value.
     */
    @JvmName("tdhcisnqgntkcjxx")
    public suspend fun deviceKey(`value`: Output<Int>) {
        this.deviceKey = value
    }

    /**
     * @param value Gets or sets the device name.
     */
    @JvmName("gvojowpdqxnsbhdy")
    public suspend fun deviceName(`value`: Output<String>) {
        this.deviceName = value
    }

    /**
     * @param value Gets or sets the disk mode.
     */
    @JvmName("myhtcaqesfbgselo")
    public suspend fun diskMode(`value`: Output<Either<String, DiskMode>>) {
        this.diskMode = value
    }

    /**
     * @param value Gets or sets the disk total size.
     */
    @JvmName("vhavqdltainvhjga")
    public suspend fun diskSizeGB(`value`: Output<Int>) {
        this.diskSizeGB = value
    }

    /**
     * @param value Gets or sets the disk backing type.
     */
    @JvmName("vmknlwlqaplenlfw")
    public suspend fun diskType(`value`: Output<Either<String, DiskType>>) {
        this.diskType = value
    }

    /**
     * @param value Gets or sets the name of the virtual disk.
     */
    @JvmName("iiikxsaopsmrfody")
    public suspend fun name(`value`: Output<String>) {
        this.name = value
    }

    /**
     * @param value Gets or sets the unit number of the disk on the controller.
     */
    @JvmName("uuftjsbfxdtngyqf")
    public suspend fun unitNumber(`value`: Output<Int>) {
        this.unitNumber = value
    }

    /**
     * @param value Gets or sets the controller id.
     */
    @JvmName("olopgsbwoxpogoli")
    public suspend fun controllerKey(`value`: Int?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.controllerKey = mapped
    }

    /**
     * @param value Gets or sets the device key value.
     */
    @JvmName("xblklppqstnlskvx")
    public suspend fun deviceKey(`value`: Int?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.deviceKey = mapped
    }

    /**
     * @param value Gets or sets the device name.
     */
    @JvmName("kddugjdjxqwggoqp")
    public suspend fun deviceName(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.deviceName = mapped
    }

    /**
     * @param value Gets or sets the disk mode.
     */
    @JvmName("hjmkdhbpnyatiokn")
    public suspend fun diskMode(`value`: Either<String, DiskMode>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.diskMode = mapped
    }

    /**
     * @param value Gets or sets the disk mode.
     */
    @JvmName("fysctyugghavvkvq")
    public fun diskMode(`value`: String) {
        val toBeMapped = Either.ofLeft<String, DiskMode>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.diskMode = mapped
    }

    /**
     * @param value Gets or sets the disk mode.
     */
    @JvmName("unpfcdkwaeqdenjp")
    public fun diskMode(`value`: DiskMode) {
        val toBeMapped = Either.ofRight<String, DiskMode>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.diskMode = mapped
    }

    /**
     * @param value Gets or sets the disk total size.
     */
    @JvmName("ooorqksvndpbovrg")
    public suspend fun diskSizeGB(`value`: Int?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.diskSizeGB = mapped
    }

    /**
     * @param value Gets or sets the disk backing type.
     */
    @JvmName("xusgueuhkbhhfdpw")
    public suspend fun diskType(`value`: Either<String, DiskType>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.diskType = mapped
    }

    /**
     * @param value Gets or sets the disk backing type.
     */
    @JvmName("djsdscjvgxdxttlj")
    public fun diskType(`value`: String) {
        val toBeMapped = Either.ofLeft<String, DiskType>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.diskType = mapped
    }

    /**
     * @param value Gets or sets the disk backing type.
     */
    @JvmName("taampbbauabfukai")
    public fun diskType(`value`: DiskType) {
        val toBeMapped = Either.ofRight<String, DiskType>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.diskType = mapped
    }

    /**
     * @param value Gets or sets the name of the virtual disk.
     */
    @JvmName("bjuxfqeudoasbpxv")
    public suspend fun name(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.name = mapped
    }

    /**
     * @param value Gets or sets the unit number of the disk on the controller.
     */
    @JvmName("gyraptaikoxsnovn")
    public suspend fun unitNumber(`value`: Int?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.unitNumber = mapped
    }

    internal fun build(): VirtualDiskArgs = VirtualDiskArgs(
        controllerKey = controllerKey,
        deviceKey = deviceKey,
        deviceName = deviceName,
        diskMode = diskMode,
        diskSizeGB = diskSizeGB,
        diskType = diskType,
        name = name,
        unitNumber = unitNumber,
    )
}
